nicfit\.console package
=======================

.. automodule:: nicfit.console
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

nicfit\.console\.ansi module
----------------------------

.. automodule:: nicfit.console.ansi
    :members:
    :undoc-members:
    :show-inheritance:


